# library(knitr)
# https://ropensci.org/blog/2019/12/08/precompute-vignettes/
# 1) Run this below.
# knitr::knit("vignettes/multiVARExample.Rmd.orig", "vignettes/multiVARExample.Rmd")
# 2) Move figures back to vignettes directory.
# 3) Remove "figures/" from "multiVARExample.Rmd" syntax. 